
from src.marcuslion.marcuslion import ml_search

if __name__ == '__main__':
    try:
        df = ml_search("bike", "kaggle,usgov")
        print(df.head(3))
        print(df.tail(3))

    except Exception as e:
        # print(e, '|', e.errno, '|', e.value, '|', e.args)
        print("Exception ", e)



import logging
import pandas as pd

logger = logging.getLogger('ml_py')
logger.setLevel(logging.DEBUG)
logger.addHandler(logging.StreamHandler())

logger.info('Start marcuslion test')

pd.set_option('display.max_rows', 500)
pd.set_option('display.max_columns', 500)
pd.set_option('display.width', 2000)

